# Changelog

<!-- insertion marker -->
## Unreleased

<small>[Compare with latest](https://github.com/QUT-Digital-Observatory/youte/compare/v2.2.2...HEAD)</small>

<!-- insertion marker -->
## [v2.2.2](https://github.com/QUT-Digital-Observatory/youte/releases/tag/v2.2.2) - 2023-05-21

<small>[Compare with v2.2.1](https://github.com/QUT-Digital-Observatory/youte/compare/v2.2.1...v2.2.2)</small>

### Bug Fixes

- flattening json to tidy to csv should not flatten list ([bf272aa](https://github.com/QUT-Digital-Observatory/youte/commit/bf272aa2460820528ba3d04bc7ac219b701dfc71) by Boyd Nguyen).

## [v2.2.1](https://github.com/QUT-Digital-Observatory/youte/releases/tag/v2.2.1) - 2023-05-16

<small>[Compare with v2.2.0](https://github.com/QUT-Digital-Observatory/youte/compare/v2.2.0...v2.2.1)</small>

### Bug Fixes

- pre-existing types' subscriptability don't work in 3.8 ([0242454](https://github.com/QUT-Digital-Observatory/youte/commit/024245498538eee0fdbd6c4de7246c6a1c524757) by Boyd Nguyen).

## [v2.2.0](https://github.com/QUT-Digital-Observatory/youte/releases/tag/v2.2.0) - 2023-05-16

<small>[Compare with v2.1.0](https://github.com/QUT-Digital-Observatory/youte/compare/v2.1.0...v2.2.0)</small>

### Features

- include metadata in parsers ([d5d79fe](https://github.com/QUT-Digital-Observatory/youte/commit/d5d79fe44c275facd9cfb0897272c38cde9ba7d8) by Boyd Nguyen).
- add _youte metadata to returned output ([d87b97f](https://github.com/QUT-Digital-Observatory/youte/commit/d87b97fd2bc9f6092ed3bc4c55dc8d229ae4283c) by Boyd Nguyen).

### Bug Fixes

- fix None outdb when file doesn't exist ([802ab8f](https://github.com/QUT-Digital-Observatory/youte/commit/802ab8f2e97af9f161175bd2f6f9e41d74288aa8) by Boyd Nguyen).
- fix KeyError in parse_video + parse_videos ([6fbbb70](https://github.com/QUT-Digital-Observatory/youte/commit/6fbbb70f320e58c4aa85c2700cecaf0bd36f91da) by Boyd Nguyen).

## [v2.1.0](https://github.com/QUT-Digital-Observatory/youte/releases/tag/v2.1.0) - 2023-04-14

<small>[Compare with v2.0.2](https://github.com/QUT-Digital-Observatory/youte/compare/v2.0.2...v2.1.0)</small>

### Features

- new 'full-archive' command ([dbaef5c](https://github.com/QUT-Digital-Observatory/youte/commit/dbaef5cf5ab9acf2b5c4eafa0b948f7f34c779ae) by Boyd Nguyen).

### Bug Fixes

- improve logging ([66a7b68](https://github.com/QUT-Digital-Observatory/youte/commit/66a7b68a4e77c34a05e0f4208fe62a00b9bd3182) by Boyd Nguyen).
- use dict.get() to allow for nullable fields when parsing JSON ([3a2e8c9](https://github.com/QUT-Digital-Observatory/youte/commit/3a2e8c9db35639b31c1911da8b3d4b6905725802) by Boyd Nguyen).
- avoid inputting error messages to output file ([4a186dc](https://github.com/QUT-Digital-Observatory/youte/commit/4a186dc2b91f2d859439e773dd1a2ec62c1e4af6) by Boyd Nguyen).
- refine resource schema + make optional fields optional ([821bca9](https://github.com/QUT-Digital-Observatory/youte/commit/821bca98e1c237bffe90cb3f3356cefc74ab8987) by Boyd Nguyen).
- fix KeyError in parse_video + parse_videos ([05ade72](https://github.com/QUT-Digital-Observatory/youte/commit/05ade72ddd7ce644b573069434db275fac105f98) by Boyd Nguyen).

## [v2.0.2](https://github.com/QUT-Digital-Observatory/youte/releases/tag/v2.0.2) - 2023-03-31

<small>[Compare with 2.0.1](https://github.com/QUT-Digital-Observatory/youte/compare/2.0.1...v2.0.2)</small>

### Bug Fixes

- fix KeyError in parse_video + parse_videos ([8e9d4fe](https://github.com/QUT-Digital-Observatory/youte/commit/8e9d4fe2385431e8fbb28bc94c1c27578cde4b2b) by Boyd Nguyen).

## [2.0.1](https://github.com/QUT-Digital-Observatory/youte/releases/tag/2.0.1) - 2023-03-20

<small>[Compare with 2.0.0](https://github.com/QUT-Digital-Observatory/youte/compare/2.0.0...2.0.1)</small>

## [2.0.0](https://github.com/QUT-Digital-Observatory/youte/releases/tag/2.0.0) - 2023-03-16

<small>[Compare with 1.3.0](https://github.com/QUT-Digital-Observatory/youte/compare/1.3.0...2.0.0)</small>

## [1.3.0](https://github.com/QUT-Digital-Observatory/youte/releases/tag/1.3.0) - 2023-02-24

<small>[Compare with 1.2.0](https://github.com/QUT-Digital-Observatory/youte/compare/1.2.0...1.3.0)</small>

## [1.2.0](https://github.com/QUT-Digital-Observatory/youte/releases/tag/1.2.0) - 2023-02-07

<small>[Compare with 1.1.0](https://github.com/QUT-Digital-Observatory/youte/compare/1.1.0...1.2.0)</small>

## [1.1.0](https://github.com/QUT-Digital-Observatory/youte/releases/tag/1.1.0) - 2022-12-06

<small>[Compare with 1.0.1](https://github.com/QUT-Digital-Observatory/youte/compare/1.0.1...1.1.0)</small>

## [1.0.1](https://github.com/QUT-Digital-Observatory/youte/releases/tag/1.0.1) - 2022-12-01

<small>[Compare with 1.0.0](https://github.com/QUT-Digital-Observatory/youte/compare/1.0.0...1.0.1)</small>

## [1.0.0](https://github.com/QUT-Digital-Observatory/youte/releases/tag/1.0.0) - 2022-11-23

<small>[Compare with 0.1.1](https://github.com/QUT-Digital-Observatory/youte/compare/0.1.1...1.0.0)</small>

## [0.1.1](https://github.com/QUT-Digital-Observatory/youte/releases/tag/0.1.1) - 2022-10-10

<small>[Compare with 0.1.0](https://github.com/QUT-Digital-Observatory/youte/compare/0.1.0...0.1.1)</small>

## [0.1.0](https://github.com/QUT-Digital-Observatory/youte/releases/tag/0.1.0) - 2022-09-21

<small>[Compare with 0.0.2](https://github.com/QUT-Digital-Observatory/youte/compare/0.0.2...0.1.0)</small>

## [0.0.2](https://github.com/QUT-Digital-Observatory/youte/releases/tag/0.0.2) - 2022-09-07

<small>[Compare with 0.0.1b](https://github.com/QUT-Digital-Observatory/youte/compare/0.0.1b...0.0.2)</small>

## [0.0.1b](https://github.com/QUT-Digital-Observatory/youte/releases/tag/0.0.1b) - 2022-09-02

<small>[Compare with first commit](https://github.com/QUT-Digital-Observatory/youte/compare/4562a2b20cdd68e305a4b51ebba3b02ba132665b...0.0.1b)</small>
